==> cometspy-0.4.18.tar.gz: cometspy-0.4.18/README.md <==

[![Current PyPI version](https://img.shields.io/pypi/v/cometspy.svg)](https://pypi.org/project/cometspy/)
[![Supported Python Versions](https://img.shields.io/pypi/pyversions/cometspy.svg)](https://pypi.org/project/cometspy/)
[![Join the chat at https://gitter.im/segrelab/comets](https://badges.gitter.im/segrelab/comets.png)](https://gitter.im/segrelab/comets?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![GitHub release](https://img.shields.io/github/release/segrelab/cometspy/all.svg)](https://GitHub.com/segrelab/cometspy/releases/)

# COMETSPy - The Python Interface for COMETS
COMETSPY is the Python interface for running [COMETS](https://GitHub.com/segrelab/comets) simulations. COMETS is built and maintained by the COMETSPy Core Team. 

COMETSPy is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

CometsPy is developed with non-commercial use in mind and is presented as-is. To inquire about collaborations or commercial usage and development, please contact us at <comets@bu.edu>.

# Documentation
Documentation on how to use COMETS with COMETSPy is found at [https://cometspy.readthedocs.io](https://cometspy.readthedocs.io/en/latest/).

# Installation
Use pip to install COMETSPy from PyPI:

```py
pip3 install cometspy
```

# Cite us

# Contributing
Contributions are welcome and appreciated. Questions and discussions can be raised on [Gitter](https://gitter.im/segrelab/comets). Issues should be discussed in this forum before they are raised on GitHub. For other questions contact us on email comets@bu.edu.

==> cometspy-0.5.2.tar.gz: cometspy-0.5.2/README.md <==

[![Current PyPI version](https://img.shields.io/pypi/v/cometspy.svg)](https://pypi.org/project/cometspy/)
[![Supported Python Versions](https://img.shields.io/pypi/pyversions/cometspy.svg)](https://pypi.org/project/cometspy/)
[![GitHub release](https://img.shields.io/github/release/segrelab/cometspy/all.svg)](https://GitHub.com/segrelab/cometspy/releases/)

# COMETSPy - The Python Interface for COMETS
COMETSPY is the Python interface for running [COMETS](https://GitHub.com/segrelab/comets) simulations. COMETS is built and maintained by the COMETSPy Core Team. 

COMETSPy is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

CometsPy is developed with non-commercial use in mind and is presented as-is. To inquire about collaborations or commercial usage and development, please contact us at <comets@bu.edu>.

# Documentation
Documentation on how to use COMETS with COMETSPy can be found at [https://cometspy.readthedocs.io/en/latest/](https://segrelab.github.io/cometspy/).

# Installation
Use pip to install COMETSPy from PyPI:

```py
pip3 install cometspy
```

# Cite us

# Contributing
Contributions are welcome and appreciated. Questions and discussions can be raised on [Gitter](https://gitter.im/segrelab/comets). Issues should be discussed in this forum before they are raised on GitHub. For other questions contact us on email comets@bu.edu.
